services

package
v1.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 6, 2023 License: GPL-3.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func StartBeaconService

func StartBeaconService() error

StartBeaconService is used to start the global beaconchain service

func StartFrontendCache added in v1.1.0

func StartFrontendCache() error

StartFrontendCache is used to start the global frontend cache service

Types

type BeaconService

type BeaconService struct {
	// contains filtered or unexported fields
}
var GlobalBeaconService *BeaconService

func (*BeaconService) CheckBlockOrphanedStatus added in v1.3.1

func (bs *BeaconService) CheckBlockOrphanedStatus(blockRoot []byte) bool

func (*BeaconService) GetBlobSidecarsByBlockRoot added in v1.1.0

func (bs *BeaconService) GetBlobSidecarsByBlockRoot(blockroot []byte) (*rpctypes.StandardV1BlobSidecarsResponse, error)

func (*BeaconService) GetCachedEpochStats

func (bs *BeaconService) GetCachedEpochStats(epoch uint64) *indexer.EpochStats

func (*BeaconService) GetCachedValidatorSet

func (bs *BeaconService) GetCachedValidatorSet() *rpctypes.StandardV1StateValidatorsResponse

func (*BeaconService) GetClients added in v1.3.0

func (bs *BeaconService) GetClients() []*indexer.IndexerClient

func (*BeaconService) GetDbBlocks

func (bs *BeaconService) GetDbBlocks(firstSlot uint64, limit int32, withOrphaned bool) []*dbtypes.Block

func (*BeaconService) GetDbBlocksByFilter added in v1.4.0

func (bs *BeaconService) GetDbBlocksByFilter(filter *dbtypes.BlockFilter, pageIdx uint64, pageSize uint32) []*dbtypes.AssignedBlock

func (*BeaconService) GetDbBlocksByParentRoot added in v1.3.0

func (bs *BeaconService) GetDbBlocksByParentRoot(parentRoot []byte) []*dbtypes.Block

func (*BeaconService) GetDbBlocksForSlots

func (bs *BeaconService) GetDbBlocksForSlots(firstSlot uint64, slotLimit uint32, withOrphaned bool) []*dbtypes.Block

func (*BeaconService) GetDbEpochs

func (bs *BeaconService) GetDbEpochs(firstEpoch uint64, limit uint32) []*dbtypes.Epoch

func (*BeaconService) GetEpochAssignments

func (bs *BeaconService) GetEpochAssignments(epoch uint64) (*rpctypes.EpochAssignments, error)

func (*BeaconService) GetFinalizedEpoch added in v1.3.0

func (bs *BeaconService) GetFinalizedEpoch() (int64, []byte)

func (*BeaconService) GetGenesis

func (*BeaconService) GetIndexer added in v1.4.0

func (bs *BeaconService) GetIndexer() *indexer.Indexer

func (*BeaconService) GetOrphanedBlock

func (bs *BeaconService) GetOrphanedBlock(blockroot []byte) *rpctypes.CombinedBlockResponse

func (*BeaconService) GetProposerAssignments

func (bs *BeaconService) GetProposerAssignments(firstEpoch uint64, lastEpoch uint64) (proposerAssignments map[uint64]uint64, synchronizedEpochs map[uint64]bool)

func (*BeaconService) GetSlotDetailsByBlockroot

func (bs *BeaconService) GetSlotDetailsByBlockroot(blockroot []byte) (*rpctypes.CombinedBlockResponse, error)

func (*BeaconService) GetSlotDetailsBySlot

func (bs *BeaconService) GetSlotDetailsBySlot(slot uint64) (*rpctypes.CombinedBlockResponse, error)

func (*BeaconService) GetValidatorActivity added in v1.1.0

func (bs *BeaconService) GetValidatorActivity() (map[uint64]uint8, uint64)

func (*BeaconService) GetValidatorName

func (bs *BeaconService) GetValidatorName(index uint64) string

type FrontendCacheProcessingPage added in v1.1.0

type FrontendCacheProcessingPage struct {
	CacheTimeout time.Duration
	// contains filtered or unexported fields
}

type FrontendCacheService added in v1.1.0

type FrontendCacheService struct {
	// contains filtered or unexported fields
}
var GlobalFrontendCache *FrontendCacheService

func (*FrontendCacheService) GetFrontendCache added in v1.1.0

func (fc *FrontendCacheService) GetFrontendCache(pageKey string, returnValue interface{}) error

func (*FrontendCacheService) ProcessCachedPage added in v1.1.0

func (fc *FrontendCacheService) ProcessCachedPage(pageKey string, caching bool, returnValue interface{}, buildFn func(pageCall *FrontendCacheProcessingPage) interface{}) interface{}

func (*FrontendCacheService) SetFrontendCache added in v1.1.0

func (fc *FrontendCacheService) SetFrontendCache(pageKey string, value interface{}, timeout time.Duration) error

type ValidatorNames

type ValidatorNames struct {
	// contains filtered or unexported fields
}

func (*ValidatorNames) GetValidatorName

func (vn *ValidatorNames) GetValidatorName(index uint64) string

func (*ValidatorNames) LoadValidatorNames added in v1.4.0

func (vn *ValidatorNames) LoadValidatorNames()

Jump to