Documentation
¶
Index ¶
- func StartBeaconService() error
- func StartFrontendCache() error
- type BeaconService
- func (bs *BeaconService) CheckBlockOrphanedStatus(blockRoot []byte) bool
- func (bs *BeaconService) GetBlobSidecarsByBlockRoot(blockroot []byte) (*rpctypes.StandardV1BlobSidecarsResponse, error)
- func (bs *BeaconService) GetCachedBlockByBlockroot(blockroot []byte) *rpctypes.CombinedBlockResponse
- func (bs *BeaconService) GetCachedBlockByStateroot(stateroot []byte) *rpctypes.CombinedBlockResponse
- func (bs *BeaconService) GetCachedEpochStats(epoch uint64) *indexer.EpochStats
- func (bs *BeaconService) GetCachedValidatorSet() *rpctypes.StandardV1StateValidatorsResponse
- func (bs *BeaconService) GetClients() []*indexer.IndexerClient
- func (bs *BeaconService) GetDbBlocks(firstSlot uint64, limit int32, withOrphaned bool) []*dbtypes.Block
- func (bs *BeaconService) GetDbBlocksByGraffiti(graffiti string, pageIdx uint64, pageSize uint32, withOrphaned bool) []*dbtypes.Block
- func (bs *BeaconService) GetDbBlocksByParentRoot(parentRoot []byte) []*dbtypes.Block
- func (bs *BeaconService) GetDbBlocksByProposer(proposer uint64, pageIdx uint64, pageSize uint32, withMissing bool, ...) []*dbtypes.AssignedBlock
- func (bs *BeaconService) GetDbBlocksForSlots(firstSlot uint64, slotLimit uint32, withOrphaned bool) []*dbtypes.Block
- func (bs *BeaconService) GetDbEpochs(firstEpoch uint64, limit uint32) []*dbtypes.Epoch
- func (bs *BeaconService) GetEpochAssignments(epoch uint64) (*rpctypes.EpochAssignments, error)
- func (bs *BeaconService) GetFinalizedEpoch() (int64, []byte)
- func (bs *BeaconService) GetGenesis() (*rpctypes.StandardV1GenesisResponse, error)
- func (bs *BeaconService) GetOrphanedBlock(blockroot []byte) *rpctypes.CombinedBlockResponse
- func (bs *BeaconService) GetProposerAssignments(firstEpoch uint64, lastEpoch uint64) (proposerAssignments map[uint64]uint64, synchronizedEpochs map[uint64]bool)
- func (bs *BeaconService) GetSlotDetailsByBlockroot(blockroot []byte, withBlobs bool) (*rpctypes.CombinedBlockResponse, error)
- func (bs *BeaconService) GetSlotDetailsBySlot(slot uint64, withBlobs bool) (*rpctypes.CombinedBlockResponse, error)
- func (bs *BeaconService) GetValidatorActivity() (map[uint64]uint8, uint64)
- func (bs *BeaconService) GetValidatorName(index uint64) string
- type FrontendCacheProcessingPage
- type FrontendCacheService
- func (fc *FrontendCacheService) GetFrontendCache(pageKey string, returnValue interface{}) error
- func (fc *FrontendCacheService) ProcessCachedPage(pageKey string, caching bool, returnValue interface{}, ...) interface{}
- func (fc *FrontendCacheService) SetFrontendCache(pageKey string, value interface{}, timeout time.Duration) error
- type ValidatorNames
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartBeaconService ¶
func StartBeaconService() error
StartBeaconService is used to start the global beaconchain service
func StartFrontendCache ¶ added in v1.1.0
func StartFrontendCache() error
StartFrontendCache is used to start the global frontend cache service
Types ¶
type BeaconService ¶
type BeaconService struct {
// contains filtered or unexported fields
}
var GlobalBeaconService *BeaconService
func (*BeaconService) CheckBlockOrphanedStatus ¶ added in v1.3.1
func (bs *BeaconService) CheckBlockOrphanedStatus(blockRoot []byte) bool
func (*BeaconService) GetBlobSidecarsByBlockRoot ¶ added in v1.1.0
func (bs *BeaconService) GetBlobSidecarsByBlockRoot(blockroot []byte) (*rpctypes.StandardV1BlobSidecarsResponse, error)
func (*BeaconService) GetCachedBlockByBlockroot ¶
func (bs *BeaconService) GetCachedBlockByBlockroot(blockroot []byte) *rpctypes.CombinedBlockResponse
func (*BeaconService) GetCachedBlockByStateroot ¶
func (bs *BeaconService) GetCachedBlockByStateroot(stateroot []byte) *rpctypes.CombinedBlockResponse
func (*BeaconService) GetCachedEpochStats ¶
func (bs *BeaconService) GetCachedEpochStats(epoch uint64) *indexer.EpochStats
func (*BeaconService) GetCachedValidatorSet ¶
func (bs *BeaconService) GetCachedValidatorSet() *rpctypes.StandardV1StateValidatorsResponse
func (*BeaconService) GetClients ¶ added in v1.3.0
func (bs *BeaconService) GetClients() []*indexer.IndexerClient
func (*BeaconService) GetDbBlocks ¶
func (*BeaconService) GetDbBlocksByGraffiti ¶
func (*BeaconService) GetDbBlocksByParentRoot ¶ added in v1.3.0
func (bs *BeaconService) GetDbBlocksByParentRoot(parentRoot []byte) []*dbtypes.Block
func (*BeaconService) GetDbBlocksByProposer ¶ added in v1.1.0
func (bs *BeaconService) GetDbBlocksByProposer(proposer uint64, pageIdx uint64, pageSize uint32, withMissing bool, withOrphaned bool) []*dbtypes.AssignedBlock
func (*BeaconService) GetDbBlocksForSlots ¶
func (*BeaconService) GetDbEpochs ¶
func (bs *BeaconService) GetDbEpochs(firstEpoch uint64, limit uint32) []*dbtypes.Epoch
func (*BeaconService) GetEpochAssignments ¶
func (bs *BeaconService) GetEpochAssignments(epoch uint64) (*rpctypes.EpochAssignments, error)
func (*BeaconService) GetFinalizedEpoch ¶ added in v1.3.0
func (bs *BeaconService) GetFinalizedEpoch() (int64, []byte)
func (*BeaconService) GetGenesis ¶
func (bs *BeaconService) GetGenesis() (*rpctypes.StandardV1GenesisResponse, error)
func (*BeaconService) GetOrphanedBlock ¶
func (bs *BeaconService) GetOrphanedBlock(blockroot []byte) *rpctypes.CombinedBlockResponse
func (*BeaconService) GetProposerAssignments ¶
func (*BeaconService) GetSlotDetailsByBlockroot ¶
func (bs *BeaconService) GetSlotDetailsByBlockroot(blockroot []byte, withBlobs bool) (*rpctypes.CombinedBlockResponse, error)
func (*BeaconService) GetSlotDetailsBySlot ¶
func (bs *BeaconService) GetSlotDetailsBySlot(slot uint64, withBlobs bool) (*rpctypes.CombinedBlockResponse, error)
func (*BeaconService) GetValidatorActivity ¶ added in v1.1.0
func (bs *BeaconService) GetValidatorActivity() (map[uint64]uint8, uint64)
func (*BeaconService) GetValidatorName ¶
func (bs *BeaconService) GetValidatorName(index uint64) string
type FrontendCacheProcessingPage ¶ added in v1.1.0
type FrontendCacheService ¶ added in v1.1.0
type FrontendCacheService struct {
// contains filtered or unexported fields
}
var GlobalFrontendCache *FrontendCacheService
func (*FrontendCacheService) GetFrontendCache ¶ added in v1.1.0
func (fc *FrontendCacheService) GetFrontendCache(pageKey string, returnValue interface{}) error
func (*FrontendCacheService) ProcessCachedPage ¶ added in v1.1.0
func (fc *FrontendCacheService) ProcessCachedPage(pageKey string, caching bool, returnValue interface{}, buildFn func(pageCall *FrontendCacheProcessingPage) interface{}) interface{}
func (*FrontendCacheService) SetFrontendCache ¶ added in v1.1.0
func (fc *FrontendCacheService) SetFrontendCache(pageKey string, value interface{}, timeout time.Duration) error
type ValidatorNames ¶
type ValidatorNames struct {
// contains filtered or unexported fields
}
func (*ValidatorNames) GetValidatorName ¶
func (vn *ValidatorNames) GetValidatorName(index uint64) string
func (*ValidatorNames) LoadFromRangesApi ¶
func (vn *ValidatorNames) LoadFromRangesApi(apiUrl string) error
func (*ValidatorNames) LoadFromYaml ¶
func (vn *ValidatorNames) LoadFromYaml(fileName string) error
Click to show internal directories.
Click to hide internal directories.